@@ -24,15 +24,15 @@ as.rolog <- function(query=quote(member(.X, ""[a, "b", 3L, 4, (pi), TRUE, .Y])))
     # Anonymous variable
     if(query == ".")
       return(expression(`_`))
-	
+
     if(substr(query, 1, 1) == ".")
       return(as.expression(as.symbol(substr(query, 2, nchar(query)))))
   }
-	
+
   if(is.call(query))
   {
     args <- as.list(query)
-	
+
     # Things like (2 + 3) or (a) are evaluated
     if(args[[1]] == "(")
       return(as.rolog(eval(args[[2]])))
@@ -40,15 +40,18 @@ as.rolog <- function(query=quote(member(.X, ""[a, "b", 3L, 4, (pi), TRUE, .Y])))
     # `[`("", 1, 2, 3), aka. ""[1, 2, 3] is a list
     if(args[[1]] == "[" & length(args[[2]]) == 1 & args[[2]] == "")
       return(lapply(args[c(-1, -2)], FUN=as.rolog))
-	
+
     # list(1, 2, 3) is a list not a call
     if(args[[1]] == "list")
       return(lapply(args[-1], FUN=as.rolog))
-	
+
     args[-1] <- lapply(args[-1], FUN=as.rolog)
       return(as.call(args))
   }
-	
+
+  if(is.function(query))
+    body(query) <- preproc(body(query))
+
   if(is.list(query))
     return(lapply(query, FUN=as.rolog))
 
